This is a mock library for greptime, it provide same API as greptime, but it's not a real library,
you can also use it to test your scripts locally first (but mock test is still in experiment phase),
then upload them to the server for execution.